@@ -57,27 +57,27 @@ extern "C"
 
 // Include files for KDE
 
-#include <klocale.h>
+#include <tdelocale.h>
 #include <klineedit.h>
-#include <kfiledialog.h>
-#include <kmessagebox.h>
+#include <tdefiledialog.h>
+#include <tdemessagebox.h>
 #include <knuminput.h>
 #include <kinstance.h>
-#include <kconfig.h>
-#include <klistbox.h>
+#include <tdeconfig.h>
+#include <tdelistbox.h>
 #include <klineeditdlg.h>
 #include <ksqueezedtextlabel.h>
-#include <kio/netaccess.h>
+#include <tdeio/netaccess.h>
 #include <kimageio.h>
-#include <ktempfile.h>
-#include <kdeversion.h>
+#include <tdetempfile.h>
+#include <tdeversion.h>
 #include <kdebug.h>
-#include <kfiletreeview.h>
-#include <kapplication.h>
-#include <kaboutdata.h>
+#include <tdefiletreeview.h>
+#include <tdeapplication.h>
+#include <tdeaboutdata.h>
 #include <khelpmenu.h>
 #include <kiconloader.h>
-#include <kpopupmenu.h>
+#include <tdepopupmenu.h>
 
 // Include files for libKipi.
 
@@ -95,7 +95,7 @@ namespace KIPIAcquireImagesPlugin
 // Used by slotOK() method.
 
 #undef NETACCESS_WIDGET
-#if KDE_VERSION >= 0x30200
+#if TDE_VERSION >= 0x30200
 #define NETACCESS_WIDGET , this
 #else
 #define NETACCESS_WIDGET
@@ -119,7 +119,7 @@ AcquireImageDialog::AcquireImageDialog( KIPI::Interface* interface, TQWidget *pa
 
     m_about = new KIPIPlugins::KPAboutData(I18N_NOOP("Acquire images"),
                                            0,
-                                           KAboutData::License_GPL,
+                                           TDEAboutData::License_GPL,
                                            I18N_NOOP("A Kipi plugin to acquire images"),
                                            "(c) 2003-2008, Gilles Caulier");
 
@@ -140,14 +140,14 @@ AcquireImageDialog::~AcquireImageDialog()
 
 void AcquireImageDialog::slotHelp()
 {
-    KApplication::kApplication()->invokeHelp("acquireimages", "kipi-plugins");
+    TDEApplication::kApplication()->invokeHelp("acquireimages", "kipi-plugins");
 }    
 
 void AcquireImageDialog::readSettings(void)
 {
     // Read all settings from configuration file.
 
-    m_config = new KConfig("kipirc");
+    m_config = new TDEConfig("kipirc");
     m_config->setGroup("AcquireImages Settings");
     m_FileName->setText(m_config->readPathEntry("DefaultImageFileName", i18n("image")));
     m_imageCompression->setValue(m_config->readNumEntry("ImageCompression", 75));
@@ -164,7 +164,7 @@ void AcquireImageDialog::writeSettings(void)
 {
     // Write all settings in configuration file.
 
-    m_config = new KConfig("kipirc");
+    m_config = new TDEConfig("kipirc");
     m_config->setGroup("AcquireImages Settings");
     m_config->writePathEntry("DefaultImageFileName", m_FileName->text());
     m_config->writeEntry("ImageCompression", m_imageCompression->value());
@@ -179,7 +179,7 @@ void AcquireImageDialog::setupImageOptions(void)
 
     page_setupImageOptions = addPage( i18n("Target Image"),
                                       i18n("Target Image Options"),
-                                      BarIcon("image", KIcon::SizeMedium ) );
+                                      BarIcon("image-x-generic", TDEIcon::SizeMedium ) );
 
     TQVBoxLayout *vlay = new TQVBoxLayout( page_setupImageOptions, 0, spacingHint() );
 
@@ -302,7 +302,7 @@ void AcquireImageDialog::setupAlbumsList(void)
 
     page_setupAlbumsList = addPage( i18n("Selection"),
                                     i18n("Album selection"),
-                                    BarIcon("folder_image", KIcon::SizeMedium ) );
+                                    BarIcon("folder_image", TDEIcon::SizeMedium ) );
 
     TQVBoxLayout *vlay = new TQVBoxLayout( page_setupAlbumsList, 0, spacingHint() );
 
@@ -428,14 +428,14 @@ void AcquireImageDialog::slotOk()
     TQString ext = extension(imageFormat);
     url.setFileName(fileName + ext);
 
-    if (KIO::NetAccess::exists(url, false NETACCESS_WIDGET)) 
+    if (TDEIO::NetAccess::exists(url, false NETACCESS_WIDGET)) 
     {
         for (int idx = 1; idx < 100 ; ++idx) 
         {
             url.setFileName(TQString("%1_%2%3").arg(fileName).arg(idx).arg(ext));
             kdDebug(51001) << "File already exist. Try to fixed target Url to: " << url.prettyURL() << endl;
             
-            if (!KIO::NetAccess::exists(url, false NETACCESS_WIDGET)) 
+            if (!TDEIO::NetAccess::exists(url, false NETACCESS_WIDGET)) 
                break;
         }
     }
@@ -478,7 +478,7 @@ void AcquireImageDialog::slotOk()
     // Upload the image if necessary
     if ( !url.isLocalFile()) 
     {
-        if (!KIO::NetAccess::upload(imagePath, url NETACCESS_WIDGET)) 
+        if (!TDEIO::NetAccess::upload(imagePath, url NETACCESS_WIDGET)) 
         {
            KMessageBox::error(this, i18n("Could not upload image to \"%1\".").arg(url.prettyURL()));
            return;
