@@ -36,16 +36,16 @@
 
 // KDE includes.
 
-#include <kapplication.h>
-#include <kconfig.h>
+#include <tdeapplication.h>
+#include <tdeconfig.h>
 #include <kcolorbutton.h>
 #include <kdialog.h>
 #include <khelpmenu.h>
-#include <klocale.h>
+#include <tdelocale.h>
 #include <klineedit.h>
 #include <knuminput.h>
 #include "kpaboutdata.h"
-#include <kpopupmenu.h>
+#include <tdepopupmenu.h>
 #include <kstandarddirs.h>
 #include <kurlrequester.h>
 
@@ -280,7 +280,7 @@ KMLExportConfig::KMLExportConfig( TQWidget* parent, const char* name)
     // About data and help button.
     m_about = new KIPIPlugins::KPAboutData(I18N_NOOP("KML Export"),
                                             0,
-                                            KAboutData::License_GPL,
+                                            TDEAboutData::License_GPL,
                                             I18N_NOOP("A Kipi plugin for kml exporting"),
                                             "(c) 2006-2007, Stéphane Pontier");
 
@@ -295,7 +295,7 @@ KMLExportConfig::KMLExportConfig( TQWidget* parent, const char* name)
     // --------------------------------------------------------------
     // Configuration file management 
 
-    config_ = new KConfig("kipirc");
+    config_ = new TDEConfig("kipirc");
     config_->setGroup("KMLExport Settings");
 
     readSettings();
@@ -328,7 +328,7 @@ void KMLExportConfig::slotOk()
 
 void KMLExportConfig::slotHelp()
 {
-    KApplication::kApplication()->invokeHelp("KMLExport", "kipi-plugins");
+    TDEApplication::kApplication()->invokeHelp("KMLExport", "kipi-plugins");
 }
 
 void KMLExportConfig::GoogleMapTargetRadioButton__toggled(bool)
