@@ -42,19 +42,19 @@
 // KDE includes.
 
 #include <khelpmenu.h>
-#include <kpopupmenu.h>
-#include <klocale.h>
-#include <kmessagebox.h>
-#include <kapplication.h>
+#include <tdepopupmenu.h>
+#include <tdelocale.h>
+#include <tdemessagebox.h>
+#include <tdeapplication.h>
 #include <kiconloader.h>
-#include <khtml_part.h>
-#include <khtmlview.h>
+#include <tdehtml_part.h>
+#include <tdehtmlview.h>
 #include <krun.h>
 #include <kdebug.h>
 #include <ksimpleconfig.h>
-#include <kdeversion.h>
+#include <tdeversion.h>
 #if KDE_IS_VERSION(3,2,0)
-#include <kwallet.h>
+#include <tdewallet.h>
 #endif
 
 // Libkipi includes.
@@ -116,7 +116,7 @@ PicasawebWindow::PicasawebWindow(KIPI::Interface* interface, const TQString &tmp
 
     m_about = new KIPIPlugins::KPAboutData(I18N_NOOP("Picasaweb Export"),
                                            0,
-                                           KAboutData::License_GPL,
+                                           TDEAboutData::License_GPL,
                                            I18N_NOOP("A Kipi plugin to export image collection to "
                                                      "Picasaweb web service."),
                                            "(c) 2007-2008, Vardhman Jain\n"
@@ -307,7 +307,7 @@ void PicasawebWindow::getToken(TQString& username, TQString& password)
 
 void PicasawebWindow::slotHelp()
 {
-    KApplication::kApplication()->invokeHelp("picasawebexport", "kipi-plugins");
+    TDEApplication::kApplication()->invokeHelp("picasawebexport", "kipi-plugins");
 }
 
 void PicasawebWindow::slotGetAlbumsListSucceeded()
