@@ -45,21 +45,21 @@
 
 // KDE includes.
 
-#include <klocale.h>
+#include <tdelocale.h>
 #include <klineedit.h>
 #include <kiconloader.h>
-#include <kfiledialog.h>
-#include <kmessagebox.h>
+#include <tdefiledialog.h>
+#include <tdemessagebox.h>
 #include <knuminput.h>
 #include <kinstance.h>
-#include <kconfig.h>
+#include <tdeconfig.h>
 #include <kdebug.h>
 #include <kdialogbase.h>
 #include <kbuttonbox.h>
 #include <ksqueezedtextlabel.h>
-#include <kapplication.h>
+#include <tdeapplication.h>
 #include <khelpmenu.h>
-#include <kpopupmenu.h>
+#include <tdepopupmenu.h>
 #include <kurlrequester.h>
 
 // LibKipi includes.
@@ -98,7 +98,7 @@ private:
 };
 
 ListImageItems::ListImageItems(TQWidget *parent, const char *name)
-              : KListBox(parent, name)
+              : TDEListBox(parent, name)
 {
     setSelectionMode (TQListBox::Extended);
     setAcceptDrops(true);
@@ -157,7 +157,7 @@ SendImagesDialog::SendImagesDialog(TQWidget *parent, KIPI::Interface* interface,
 
     m_about = new KIPIPlugins::KPAboutData(I18N_NOOP("Send Images"),
                                            0,
-                                           KAboutData::License_GPL,
+                                           TDEAboutData::License_GPL,
                                            I18N_NOOP("A Kipi plugin for emailing images"),
                                            "(c) 2003-2007, Gilles Caulier");
 
@@ -191,7 +191,7 @@ void SendImagesDialog::readSettings(void)
 {
     // Read all settings from configuration file.
     
-    KConfig config("kipirc");
+    TDEConfig config("kipirc");
     config.setGroup("SendImages Settings");
 
     TQString t = config.readEntry("MailAgentName", "Default");
@@ -230,7 +230,7 @@ void SendImagesDialog::writeSettings(void)
 {
     // Write all settings in configuration file.
 
-    KConfig config("kipirc");
+    TDEConfig config("kipirc");
     config.setGroup("SendImages Settings");
     config.writeEntry("MailAgentName", m_mailAgentName->currentText());
     config.writeEntry("ThunderbirdBinPath", m_ThunderbirdBinPath->url());
@@ -250,7 +250,7 @@ void SendImagesDialog::setupImagesList(void)
 
     page_setupImagesList = addPage(i18n("Images"),
                                    i18n("Images to EMail"),
-                                   BarIcon("image", KIcon::SizeMedium));
+                                   BarIcon("image-x-generic", TDEIcon::SizeMedium));
 
     TQVBoxLayout *vlay = new TQVBoxLayout( page_setupImagesList, 0, spacingHint() );
 
@@ -363,7 +363,7 @@ void SendImagesDialog::setupEmailOptions(void)
 
     page_setupEmailOptions = addPage(i18n("Mail"),
                                      i18n("Mail Options"),
-                                     BarIcon("mail_generic", KIcon::SizeMedium));
+                                     BarIcon("mail_generic", TDEIcon::SizeMedium));
 
     TQVBoxLayout *vlay = new TQVBoxLayout( page_setupEmailOptions, 0, spacingHint() );
 
@@ -553,7 +553,7 @@ void SendImagesDialog::setupEmailOptions(void)
 
 void SendImagesDialog::slotHelp()
 {
-    KApplication::kApplication()->invokeHelp("sendimages", "kipi-plugins");
+    TDEApplication::kApplication()->invokeHelp("sendimages", "kipi-plugins");
 }
 
 void SendImagesDialog::slotMailAgentChanged(int)
@@ -627,7 +627,7 @@ void SendImagesDialog::slotImageSelected( TQListBoxItem * item )
     if ( m_thumbJob ) 
         delete m_thumbJob;
 
-    m_thumbJob = KIO::filePreview( pitem->url(), m_imageLabel->height() );
+    m_thumbJob = TDEIO::filePreview( pitem->url(), m_imageLabel->height() );
 
     connect(m_thumbJob, TQT_SIGNAL(gotPreview(const KFileItem*, const TQPixmap&)),
             TQT_SLOT(slotGotPreview(const KFileItem*, const TQPixmap&)));
