@@ -25,7 +25,7 @@ class TQListView;
 class TQPushButton;
 class TQSpinBox;
 class TQCheckBox;
-class KHTMLPart;
+class TDEHTMLPart;
 
 namespace KIPIGalleryExportPlugin
 {
@@ -33,7 +33,7 @@ namespace KIPIGalleryExportPlugin
 class GalleryWidget : public TQWidget
 {
     Q_OBJECT
-  TQ_OBJECT
+  
     
 public:
 
@@ -47,7 +47,7 @@ private slots:
 private:
 
     TQListView*    m_albumView;
-    KHTMLPart*    m_photoView;
+    TDEHTMLPart*    m_photoView;
     TQPushButton*  m_newAlbumBtn;
     TQPushButton*  m_addPhotoBtn;
     TQCheckBox*    m_resizeCheckBox;
